# OrderLineItemType

The type of the Order Line Item (OLI).   You can update this field only for a sales OLI and only when the sales OLI is in the `Executing` state (when the `itemState` field is set as `Executing`). 

## Enum

* `PRODUCT` (value: `'Product'`)

* `FEE` (value: `'Fee'`)

* `SERVICES` (value: `'Services'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


